@@ -1,15 +1,19 @@
 from .core import (
     DatabasesCRUDRouter,
+    GinoCRUDRouter,
     MemoryCRUDRouter,
     OrmarCRUDRouter,
     SQLAlchemyCRUDRouter,
     TortoiseCRUDRouter,
 )
 
+from ._version import __version__  # noqa: F401
+
 __all__ = [
     "MemoryCRUDRouter",
     "SQLAlchemyCRUDRouter",
     "DatabasesCRUDRouter",
     "TortoiseCRUDRouter",
     "OrmarCRUDRouter",
+    "GinoCRUDRouter",
 ]
